==> pierogi_1.1.27.tar.gz: pierogi-1.1.27/keysets/harmankardon.h <==
//
// harmankardon.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef HARMANKARDON_H
#define HARMANKARDON_H

#include "pirkeysetmetadata.h"

class QObject;

class HarmanKardonAmp1: public PIRKeysetMetaData
{
public:
  HarmanKardonAmp1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonAmp2: public PIRKeysetMetaData
{
public:
  HarmanKardonAmp2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonReceiver2: public PIRKeysetMetaData
{
public:
  HarmanKardonReceiver2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonTape1: public PIRKeysetMetaData
{
public:
  HarmanKardonTape1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonDVD1: public PIRKeysetMetaData
{
public:
  HarmanKardonDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonDVD1a: public HarmanKardonDVD1
{
public:
  HarmanKardonDVD1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonCD1: public PIRKeysetMetaData
{
public:
  HarmanKardonCD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonCD2: public PIRKeysetMetaData
{
public:
  HarmanKardonCD2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // HARMANKARDON_H

==> pierogi_1.1.33.tar.gz: pierogi-1.1.33/keysets/harmankardon.h <==
//
// harmankardon.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef HARMANKARDON_H
#define HARMANKARDON_H

#include "pirkeysetmetadata.h"

class QObject;
class QComboBox;

class HarmanKardonAmp1: public PIRKeysetMetaData
{
public:
  HarmanKardonAmp1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class HarmanKardonAmp2: public PIRKeysetMetaData
{
public:
  HarmanKardonAmp2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class HarmanKardonReceiver2: public PIRKeysetMetaData
{
public:
  HarmanKardonReceiver2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonTape1: public PIRKeysetMetaData
{
public:
  HarmanKardonTape1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonDVD1: public PIRKeysetMetaData
{
public:
  HarmanKardonDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonDVD1a: public HarmanKardonDVD1
{
public:
  HarmanKardonDVD1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonCD1: public PIRKeysetMetaData
{
public:
  HarmanKardonCD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class HarmanKardonCD2: public PIRKeysetMetaData
{
public:
  HarmanKardonCD2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // HARMANKARDON_H
